==> fop2-2.24-debian-x86_64.tgz: fop2/html/lang/ru.php <==
<?
$mylang = "ru";
$lang[$mylang] = Array();

$lang[$mylang]['Manage Phonebook']               = "Управление телефонной книгой";
$lang[$mylang]['Add']                            = "Добавить";
$lang[$mylang]['Add Record']                     = "Добавить запись";
$lang[$mylang]['Export']                         = "Экспорт";
$lang[$mylang]['Import']                         = "Импорт";
$lang[$mylang]['No records found']               = "Не найдено записей";
$lang[$mylang]['First']                          = "Первый";
$lang[$mylang]['Previous']                       = "Предидущая";
$lang[$mylang]['Next']                           = "Следующая";
$lang[$mylang]['Last']                           = "Последняя";
$lang[$mylang]['Page']                           = "Страница";
$lang[$mylang]['of']                             = "из";
$lang[$mylang]['Total records found']            = "Всего найдено записей";
$lang[$mylang]['Cancel']                         = "Отмена";
$lang[$mylang]['View Record']                    = "Просмотр записи";
$lang[$mylang]['Edit Record']                    = "Редактирование записи";
$lang[$mylang]['Record inserted']                = "Вставка записи";
$lang[$mylang]['File was uploaded successfully'] = "Файл успешно загружен";
$lang[$mylang]['Success!']                       = "Успешно!";
$lang[$mylang]['Record updated']                 = "Запись обновлена";
$lang[$mylang]['Are you sure?']                  = "Вы уверены?";
$lang[$mylang]['An error has occurred']          = "Произошла ошибка";
$lang[$mylang]['Record deleted']                 = "Запись удалена";
$lang[$mylang]['Delete Marked']                  = "Удалить помеченное";
$lang[$mylang]['Could not upload file']          = "Не удалось загрузить файл";
$lang[$mylang]['Empty file?']                    = "Пустой файл?";

$lang[$mylang]['First Name'] = "Имя";
$lang[$mylang]['Last Name']  = "Фамилия";
$lang[$mylang]['Company']    = "Компания";
$lang[$mylang]['Phone 1']    = "Телефон-1";
$lang[$mylang]['Phone 2']    = "Телефон-2";
$lang[$mylang]['Picture']    = "Картинка";
$lang[$mylang]['Search']     = "Поиск";
$lang[$mylang]['Private']    = "Личное";

==> fop2-2.29.03-debian-x86_64.tgz: fop2/html/lang/ru.php <==
<?php
$mylang = "ru";
$lang[$mylang] = Array();

$lang[$mylang]['Manage Phonebook']               = "Управление телефонной книгой";
$lang[$mylang]['Add']                            = "Добавить";
$lang[$mylang]['Add Record']                     = "Добавить запись";
$lang[$mylang]['Export']                         = "Экспорт";
$lang[$mylang]['Import']                         = "Импорт";
$lang[$mylang]['No records found']               = "Не найдено записей";
$lang[$mylang]['First']                          = "Первая";
$lang[$mylang]['Previous']                       = "Предыдущая";
$lang[$mylang]['Next']                           = "Следующая";
$lang[$mylang]['Last']                           = "Последняя";
$lang[$mylang]['Page']                           = "Страница";
$lang[$mylang]['of']                             = "из";
$lang[$mylang]['Total records found']            = "Всего найдено записей";
$lang[$mylang]['Cancel']                         = "Отмена";
$lang[$mylang]['View Record']                    = "Просмотр записи";
$lang[$mylang]['Edit Record']                    = "Редактирование записи";
$lang[$mylang]['Record inserted']                = "Вставка записи";
$lang[$mylang]['File was uploaded successfully'] = "Файл успешно загружен";
$lang[$mylang]['Success!']                       = "Успешно!";
$lang[$mylang]['Record updated']                 = "Запись обновлена";
$lang[$mylang]['Are you sure?']                  = "Вы уверены?";
$lang[$mylang]['An error has occurred']          = "Произошла ошибка";
$lang[$mylang]['Record deleted']                 = "Запись удалена";
$lang[$mylang]['Delete Marked']                  = "Удалить помеченное";
$lang[$mylang]['Delete']                         = "Удалить";
$lang[$mylang]['Save']                           = "Сохранить";
$lang[$mylang]['Could not upload file']          = "Не удалось загрузить файл";
$lang[$mylang]['Empty file?']                    = "Пустой файл?";

$lang[$mylang]['First Name'] = "Имя";
$lang[$mylang]['Last Name']  = "Фамилия";
$lang[$mylang]['Company']    = "Компания";
$lang[$mylang]['Phone 1']    = "Телефон 1";
$lang[$mylang]['Phone 2']    = "Телефон 2";
$lang[$mylang]['Picture']    = "Картинка";
$lang[$mylang]['Search']     = "Поиск";
$lang[$mylang]['Private']    = "Личная";
$lang[$mylang]['Upload']     = "Загрузить";
